Changelog
=========


0.1.23 (2018-01-15)
-------------------

New
~~~
- Elib.path no accept *args as input. [132nd-etcher]


0.1.22 (2018-01-15)
-------------------

New
~~~
- Add param to create folders. [132nd-etcher]


0.1.20 (2018-01-03)
-------------------

Fix
~~~
- Fix that darn "must_exit" typo (finally) [132nd-etcher]

Other
~~~~~
- Merge remote-tracking branch 'origin/master' [132nd-etcher]

  # Conflicts:
  #	CHANGELOG.rst
- Merge remote-tracking branch 'origin/develop' into develop. [132nd-
  etcher]


0.1.19 (2018-01-02)
-------------------

Changes
~~~~~~~
- Export all modules in the package. [132nd-etcher]


0.1.18 (2018-01-02)
-------------------

New
~~~
- Add console utilities. [132nd-etcher]

Fix
~~~
- Linting. [132nd-etcher]


0.1.17 (2017-12-27)
-------------------

Changes
~~~~~~~
- I'm always working with absolute paths. [132nd-etcher]


0.1.16 (2017-12-27)
-------------------

New
~~~
- Add ensure_file and ensure_dir. [132nd-etcher]


0.1.15 (2017-12-27)
-------------------

New
~~~
- Add Path utils. [132nd-etcher]


0.1.11 (2017-12-24)
-------------------

Changes
~~~~~~~
- TTS slow sounds retarded Oo. [132nd-etcher]


0.1.10 (2017-12-24)
-------------------

New
~~~
- Add TTS. [132nd-etcher]
- Add tests for random utils. [132nd-etcher]
- Add random bytes function. [132nd-etcher]
- Add TTS utils. [132nd-etcher]


0.1.9 (2017-12-24)
------------------

Fix
~~~
- Set custom logger default level to DEBUG. [132nd-etcher]


0.1.7 (2017-12-23)
------------------

New
~~~
- Add logging. [132nd-etcher]
- Add random module. [132nd-etcher]


0.1.5 (2017-12-17)
------------------

Changes
~~~~~~~
- Clean setup. [132nd-etcher]
- Install versioneer. [132nd-etcher]
- Switch to pipenv for reqs. [132nd-etcher]

Fix
~~~
- Fix epab config. [132nd-etcher]
- Fix epab config. [132nd-etcher]


0.1.4 (2017-09-03)
------------------

Fix
~~~
- Don't cast str on all returns. [132nd-etcher]
- Fix namespaces. [132nd-etcher]


0.1.0 (2017-09-02)
------------------

New
~~~
- Add config. [132nd-etcher]

Other
~~~~~
- Remove __main__ [132nd-etcher]
- Initial commit. [132nd-etcher]